#!/usr/bin/env python2
# -*- coding: utf-8 -*-
##################################################
# GNU Radio Python Flow Graph
# Title: Fm Radio
# Generated: Fri Apr 28 17:17:51 2017
##################################################

if __name__ == '__main__':
	import ctypes
	import sys
	if sys.platform.startswith('linux'):
		try:
			x11 = ctypes.cdll.LoadLibrary('libX11.so')
			x11.XInitThreads()
		except:
			print "Warning: failed to XInitThreads()"

from PyQt4 import Qt
from gnuradio import analog
from gnuradio import audio
from gnuradio import eng_notation
from gnuradio import filter
from gnuradio import gr
from gnuradio import qtgui
from gnuradio.eng_option import eng_option
from gnuradio.filter import firdes
from gnuradio.qtgui import Range, RangeWidget
from optparse import OptionParser
import osmosdr
import sip
import sys
import time


class fm_radio(gr.top_block, Qt.QWidget):

	def __init__(self):
		gr.top_block.__init__(self, "Fm Radio")
		Qt.QWidget.__init__(self)
		self.setWindowTitle("Fm Radio")
		try:
			self.setWindowIcon(Qt.QIcon.fromTheme('gnuradio-grc'))
		except:
			pass
		self.top_scroll_layout = Qt.QVBoxLayout()
		self.setLayout(self.top_scroll_layout)
		self.top_scroll = Qt.QScrollArea()
		self.top_scroll.setFrameStyle(Qt.QFrame.NoFrame)
		self.top_scroll_layout.addWidget(self.top_scroll)
		self.top_scroll.setWidgetResizable(True)
		self.top_widget = Qt.QWidget()
		self.top_scroll.setWidget(self.top_widget)
		self.top_layout = Qt.QVBoxLayout(self.top_widget)
		self.top_grid_layout = Qt.QGridLayout()
		self.top_layout.addLayout(self.top_grid_layout)

		self.settings = Qt.QSettings("GNU Radio", "fm_radio")
		self.restoreGeometry(self.settings.value("geometry").toByteArray())

		##################################################
		# Variables
		##################################################
		self.samp_rate = samp_rate = 48e3
		self.freq = freq = 218013000

		##################################################
		# Blocks
		##################################################
		self._freq_range = Range(52e6, 2e9, 1e3, 218013000, 200)
		self._freq_win = RangeWidget(self._freq_range, self.set_freq, "freq", "counter_slider", float)
		self.top_grid_layout.addWidget(self._freq_win, 0,0)
		self.rtlsdr_source_0 = osmosdr.source( args="numchan=" + str(1) + " " + '' )
		self.rtlsdr_source_0.set_sample_rate(samp_rate*8*4)
		self.rtlsdr_source_0.set_center_freq(freq, 0)
		self.rtlsdr_source_0.set_freq_corr(0, 0)
		self.rtlsdr_source_0.set_dc_offset_mode(0, 0)
		self.rtlsdr_source_0.set_iq_balance_mode(0, 0)
		self.rtlsdr_source_0.set_gain_mode(False, 0)
		self.rtlsdr_source_0.set_gain(20, 0)
		self.rtlsdr_source_0.set_if_gain(20, 0)
		self.rtlsdr_source_0.set_bb_gain(20, 0)
		self.rtlsdr_source_0.set_antenna('', 0)
		self.rtlsdr_source_0.set_bandwidth(0, 0)
		  
		self.rational_resampler_xxx_0_0 = filter.rational_resampler_ccc(
				interpolation=1,
				decimation=8,
				taps=None,
				fractional_bw=None,
		)
		self.rational_resampler_xxx_0 = filter.rational_resampler_fff(
				interpolation=1,
				decimation=4,
				taps=None,
				fractional_bw=None,
		)
		self.qtgui_sink_x_1 = qtgui.sink_f(
			1024, #fftsize
			firdes.WIN_BLACKMAN_hARRIS, #wintype
			0, #fc
			samp_rate*8, #bw
			"", #name
			True, #plotfreq
			True, #plotwaterfall
			True, #plottime
			True, #plotconst
		)
		self.qtgui_sink_x_1.set_update_time(1.0/10)
		self._qtgui_sink_x_1_win = sip.wrapinstance(self.qtgui_sink_x_1.pyqwidget(), Qt.QWidget)
		self.top_grid_layout.addWidget(self._qtgui_sink_x_1_win, 10,0)
		
		self.qtgui_sink_x_1.enable_rf_freq(False)
		
		
		  
		self.qtgui_sink_x_0 = qtgui.sink_c(
			1024, #fftsize
			firdes.WIN_BLACKMAN_hARRIS, #wintype
			0, #fc
			samp_rate*8*4, #bw
			"", #name
			True, #plotfreq
			True, #plotwaterfall
			True, #plottime
			True, #plotconst
		)
		self.qtgui_sink_x_0.set_update_time(1.0/10)
		self._qtgui_sink_x_0_win = sip.wrapinstance(self.qtgui_sink_x_0.pyqwidget(), Qt.QWidget)
		self.top_grid_layout.addWidget(self._qtgui_sink_x_0_win, 9,0)
		
		self.qtgui_sink_x_0.enable_rf_freq(False)
		
		
		  
		self.audio_sink_0 = audio.sink(int(samp_rate), '', True)
		self.analog_wfm_rcv_0 = analog.wfm_rcv(
			quad_rate=samp_rate*8,
			audio_decimation=1,
		)

		##################################################
		# Connections
		##################################################
		self.connect((self.analog_wfm_rcv_0, 0), (self.qtgui_sink_x_1, 0))	
		self.connect((self.analog_wfm_rcv_0, 0), (self.rational_resampler_xxx_0, 0))	
		self.connect((self.rational_resampler_xxx_0, 0), (self.audio_sink_0, 0))	
		self.connect((self.rational_resampler_xxx_0_0, 0), (self.analog_wfm_rcv_0, 0))	
		self.connect((self.rtlsdr_source_0, 0), (self.qtgui_sink_x_0, 0))	
		self.connect((self.rtlsdr_source_0, 0), (self.rational_resampler_xxx_0_0, 0))	

	def closeEvent(self, event):
		self.settings = Qt.QSettings("GNU Radio", "fm_radio")
		self.settings.setValue("geometry", self.saveGeometry())
		event.accept()

	def get_samp_rate(self):
		return self.samp_rate

	def set_samp_rate(self, samp_rate):
		self.samp_rate = samp_rate
		self.rtlsdr_source_0.set_sample_rate(self.samp_rate*8*4)
		self.qtgui_sink_x_1.set_frequency_range(0, self.samp_rate*8)
		self.qtgui_sink_x_0.set_frequency_range(0, self.samp_rate*8*4)

	def get_freq(self):
		return self.freq

	def set_freq(self, freq):
		self.freq = freq
		self.rtlsdr_source_0.set_center_freq(self.freq, 0)


def main(top_block_cls=fm_radio, options=None):

	from distutils.version import StrictVersion
	if StrictVersion(Qt.qVersion()) >= StrictVersion("4.5.0"):
		style = gr.prefs().get_string('qtgui', 'style', 'raster')
		Qt.QApplication.setGraphicsSystem(style)
	qapp = Qt.QApplication(sys.argv)

	tb = top_block_cls()
	tb.start()
	tb.show()

	def quitting():
		tb.stop()
		tb.wait()
	qapp.connect(qapp, Qt.SIGNAL("aboutToQuit()"), quitting)
	qapp.exec_()


if __name__ == '__main__':
	main()
